@@ -2,6 +2,7 @@
 // SPDX-License-Identifier: Apache-2.0
 // SPDX-License-Identifier: MIT
 
+use itertools::Itertools;
 use json_patch::merge;
 use serde_json::Value as JsonValue;
 
@@ -172,11 +173,11 @@ fn get_internal(
     || config_path.extension() == Some(OsStr::new("json5"))
   {
     let schema: JsonValue = serde_json::from_str(include_str!("../../config.schema.json"))?;
-    let schema = jsonschema::JSONSchema::compile(&schema).unwrap();
-    let result = schema.validate(&config);
-    if let Err(errors) = result {
+    let validator = jsonschema::validator_for(&schema).expect("Invalid schema");
+    let mut errors = validator.iter_errors(&config).peekable();
+    if errors.peek().is_some() {
       for error in errors {
-        let path = error.instance_path.clone().into_vec().join(" > ");
+        let path = error.instance_path.into_iter().join(" > ");
         if path.is_empty() {
           log::error!("`{}` error: {}", config_file_name, error);
         } else {
